@@ -32,15 +32,17 @@ import time
 # cli specific imports
 from .ui_utils import menu_options, app_header, format_msg
 from .utils import (get_correct_answer, ask_yes_no, path_fixer,
-                    SetupConfig, _directory_fixer)
+                    SetupConfig, _directory_fixer, install_client_package,
+                    write_client_config)
 
 # framework stuff
 from not_so_tuf import NotSoTuf
 from not_so_tuf.client import Client
+from not_so_tuf.filecrypt import FileCrypt
 from not_so_tuf.key_handler import KeyHandler
 from not_so_tuf.package_handler import PackageHandler
 from not_so_tuf.uploader import Uploader
-from not_so_tuf.utils import FileCrypt, _cwd
+from not_so_tuf.utils import _cwd
 from not_so_tuf.version import __version__
 
 
@@ -50,6 +52,8 @@ h = logging.NullHandler()
 h.setLevel(logging.DEBUG)
 log.addHandler(h)
 
+FROZEN = getattr(sys, 'frozen', False)
+
 
 class Ui(object):
 
@@ -127,6 +131,8 @@ class Ui(object):
         self.uploader.set_uploader('s3')
         if self.uploader.ready:
             self.uploader.upload()
+            time.sleep(3)
+            self.main()
         else:
             del self.uploader
             msg = ('I told you to update your settings right? Right! Press '
@@ -394,6 +400,7 @@ class Ui(object):
         with open(filename, 'w') as f:
             f.write(pickle.dumps(obj))
         fc.encrypt()
+        write_config(self.nst)
 
     def load_config(self):
         log.debug('Loading Config')
@@ -403,6 +410,7 @@ class Ui(object):
         with open(filename, 'r') as f:
             config_data = pickle.loads(f.read())
         fc.encrypt()
+        write_config(config_data)
         return config_data
 
     def copy_decrypted_config(self):
@@ -432,7 +440,7 @@ class ClientConfig(object):
 
 def main():
     try:
-        if getattr(sys, 'frozen', False):
+        if FROZEN:
             nst = NotSoTuf(__name__, ClientConfig())
             client = Client(nst)
             print 'Current Version {}'.format(__version__)
@@ -440,6 +448,7 @@ def main():
             update = client.update_check('Not So TUF', __version__)
             if update and not client.up_to_date:
                 client.install_restart()
+            install_client_package()
         try:
             ui = Ui()
             ui.start()
