@@ -20,14 +20,17 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
+import bz2
 import hashlib
 import logging
 import os
+import sys
 
 from .file_downloader import FileDownloader
 from .utils import (ChDir, _version_string_to_tuple,
                     _version_tuple_to_string, platform_)
 
+from cStringIO import StringIO as BytesIO
 try:
     import bsdiff4
 except ImportError:
@@ -78,9 +81,6 @@ class Patcher(object):
         log.info('Starting patch updater...')
         # Check hash on installed binary to begin patching
         binary_check = self._verify_installed_binary()
-        if bsdiff4 is None:
-            log.warning('bsdiff4 not installed')
-            return False
         if not binary_check:
             log.warning('Binary check failed...')
             return False
@@ -251,3 +251,69 @@ class Patcher(object):
             _hash = hashlib.md5(f.read()).hexdigest()
             log.debug('Hash for file {}: {}'.format(package, _hash))
         return _hash
+
+
+class bsdiff4_py(object):
+    """Pure-python version of bsdiff4 module that can only patch, not diff.
+
+    By providing a pure-python fallback, we don't force frozen apps to
+    bundle the bsdiff module in order to make use of patches.  Besides,
+    the patch-applying algorithm is very simple.
+    """
+    @staticmethod
+    def patch(source, patch):
+        #  Read the length headers
+        l_bcontrol = _decode_offt(patch[8:16])
+        l_bdiff = _decode_offt(patch[16:24])
+        l_target = _decode_offt(patch[24:32])
+        #  Read the three data blocks
+        e_bcontrol = 32 + l_bcontrol
+        e_bdiff = e_bcontrol + l_bdiff
+        bcontrol = bz2.decompress(patch[32:e_bcontrol])
+        bdiff = bz2.decompress(patch[e_bcontrol:e_bdiff])
+        bextra = bz2.decompress(patch[e_bdiff:])
+        #  Decode the control tuples
+        tcontrol = []
+        for i in xrange(0, len(bcontrol), 24):
+            tcontrol.append((
+                _decode_offt(bcontrol[i:i+8]),
+                _decode_offt(bcontrol[i+8:i+16]),
+                _decode_offt(bcontrol[i+16:i+24]),
+            ))
+        #  Actually do the patching.
+        #  This is the bdiff4 patch algorithm in slow, pure python.
+        source = BytesIO(source)
+        result = BytesIO()
+        bdiff = BytesIO(bdiff)
+        bextra = BytesIO(bextra)
+        for (x, y, z) in tcontrol:
+            diff_data = bdiff.read(x)
+            orig_data = source.read(x)
+            if sys.version_info[0] < 3:
+                for i in xrange(len(diff_data)):
+                    result.write(chr((ord(diff_data[i]) +
+                                 ord(orig_data[i])) % 256))
+            else:
+                for i in xrange(len(diff_data)):
+                    result.write(bytes([(diff_data[i] + orig_data[i]) % 256]))
+            result.write(bextra.read(y))
+            source.seek(z, os.SEEK_CUR)
+        return result.getvalue()
+
+if bsdiff4 is None:
+    bsdiff4 = bsdiff4_py
+
+def _decode_offt(bytes):
+    """Decode an off_t value from a string.
+
+    This decodes a signed integer into 8 bytes.  I'd prefer some sort of
+    signed vint representation, but this is the format used by bsdiff4.
+    """
+    if sys.version_info[0] < 3:
+        bytes = map(ord, bytes)
+    x = bytes[7] & 0x7F
+    for b in xrange(6, -1, -1):
+        x = x * 256 + bytes[b]
+    if bytes[7] & 0x80:
+        x = -x
+    return x
