@@ -113,7 +113,7 @@ class Uploader(object):
 
         files = _remove_hidden_stuff_mac(os.listdir(self.deploy_dir))
         if 's3' in requested_uploader and len(requested_uploader) == 2:
-            if self.access_key is None and self.secret_key is not None \
+            if self.access_key is not None and self.secret_key is not None \
                     and self.bucket_name is not None:
                     self.ready = True
                     self.uploader = S3Uploader(file_list=files,
